@@ -3,7 +3,7 @@ use warnings;
 
 package OPCUA::Open62541::Test::Client;
 use OPCUA::Open62541::Test::Logger;
-use OPCUA::Open62541 qw(:statuscode :clientstate);
+use OPCUA::Open62541 qw(STATUSCODE_GOOD :CLIENTSTATE);
 use Carp 'croak';
 use Time::HiRes qw(sleep);
 
@@ -105,6 +105,8 @@ sub stop {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 OPCUA::Open62541::Test::Client - run open62541 client for testing
